# frozen_string_literal: true

# Code coverage
require "simplecov"

SimpleCov.start do
  # any custom configs like groups and filters can be here at a central place

  # Standard filters
  add_filter "lib/os_map_ref/version"
  # It's standard to ignore the spec folder when determining coverage
  add_filter "/spec/"

  # You can make Simplecov ignore sections of by wrapping them in # :nocov:
  # tags. However without knowledge of this `nocov` doesn't mean a lot so here
  # we take advantage of a feature that allows us to use a custom token to do
  # the same thing `nocov` does. Now in our code any sections we want to exclude
  # from test coverage stats we wrap in # :simplecov_ignore: tokens.
  # https://github.com/colszowka/simplecov#ignoringskipping-code
  nocov_token "simplecov_ignore"
end

require_relative "../lib/os_map_ref"

RSpec.configure do |config|

  config.expect_with :rspec do |expectations|
    # This option will default to `true` in RSpec 4. It makes the `description`
    # and `failure_message` of custom matchers include text for helper methods
    # defined using `chain`, e.g.:
    #     be_bigger_than(2).and_smaller_than(4).description
    #     # => "be bigger than 2 and smaller than 4"
    # ...rather than:
    #     # => "be bigger than 2"
    expectations.include_chain_clauses_in_custom_matcher_descriptions = true
  end
  config.mock_with :rspec do |mocks|
    # Prevents you from mocking or stubbing a method that does not exist on
    # a real object. This is generally recommended, and will default to
    # `true` in RSpec 4.
    mocks.verify_partial_doubles = true
  end

  # This setting enables warnings. It's recommended, but in some cases may
  # be too noisy due to issues in dependencies.
  config.warnings = true

  # Many RSpec users commonly either run the entire suite or an individual
  # file, and it's useful to allow more verbose output when running an
  # individual spec file.
  if config.files_to_run.one?
    # Use the documentation formatter for detailed output,
    # unless a formatter has already been configured
    # (e.g. via a command-line flag).
    config.default_formatter = "doc"
  end

  # Print the 10 slowest examples and example groups at the
  # end of the spec run, to help surface which specs are running
  # particularly slow.
  # config.profile_examples = 2

  # Run specs in random order to surface order dependencies. If you find an
  # order dependency and want to debug it, you can fix the order by providing
  # the seed, which is printed after each run.
  #     --seed 1234
  config.order = :random

  # Seed global randomization in this process using the `--seed` CLI option.
  # Setting this allows you to use `--seed` to deterministically reproduce
  # test failures related to randomization by passing the same `--seed` value
  # as the one that triggered the failure.
  Kernel.srand config.seed

end
